package com.cooleshow.teacher.ui.main;

import android.text.TextUtils;
import android.view.View;

import com.alibaba.android.arouter.launcher.ARouter;
import com.cooleshow.base.common.WebConstants;
import com.cooleshow.base.router.RouterPath;
import com.cooleshow.base.ui.fragment.BaseMVPFragment;
import com.cooleshow.base.utils.GlideUtils;
import com.cooleshow.base.utils.Utils;
import com.cooleshow.teacher.R;
import com.cooleshow.teacher.bean.TeacherUserInfo;
import com.cooleshow.teacher.constants.TeacherInfoConstants;
import com.cooleshow.teacher.contract.MineContract;
import com.cooleshow.teacher.databinding.FragmentMineLayoutBinding;
import com.cooleshow.teacher.presenter.main.MinePresenter;
import com.cooleshow.usercenter.helper.UserHelper;

/**
 * Author by pq, Date on 2022/5/9.
 */
public class MineFragment extends BaseMVPFragment<FragmentMineLayoutBinding, MinePresenter> implements MineContract.MineView, View.OnClickListener {

    @Override
    protected void initView(View rootView) {
        Utils.setHeadView(mViewBinding.viewStatusBar, requireContext(), 0);
        mViewBinding.ivCertificationStatus.setOnClickListener(this);
        mViewBinding.ivUnCertificationTip.setOnClickListener(this);
        mViewBinding.ivMinePage.setOnClickListener(this);
        mViewBinding.tvMinePage.setOnClickListener(this);
    }

    @Override
    protected void initData() {

    }

    public void getTeacherInfoSuccess(TeacherUserInfo teacherUserInfo) {
        if (isDetached() || !isAdded()) {
            return;
        }
        //头像
        GlideUtils.INSTANCE.loadImage(requireContext(), teacherUserInfo.heardUrl, mViewBinding.ivAvatar);
        //昵称
        mViewBinding.tvNickname.setText(UserHelper.getTeacherName(teacherUserInfo.username, teacherUserInfo.userId));
        //星级
        mViewBinding.ratingBar.setRating(teacherUserInfo.starGrade);
        //粉丝数
        mViewBinding.tvFansNum.setText(teacherUserInfo.fansNum);
        //已上课时数
        mViewBinding.tvCourseNumCompleted.setText(teacherUserInfo.expTime);
        //未上课时数
        mViewBinding.tvCourseNumNotStart.setText(teacherUserInfo.unExpTime);

        if (TextUtils.equals(teacherUserInfo.entryStatus, TeacherInfoConstants.ENTRY_STATUS_DOING)) {
            //入驻审核中
            mViewBinding.ivCertificationStatus.setImageResource(R.drawable.icon_home_entry_doing);
            mViewBinding.ivCertificationStatus.setVisibility(View.VISIBLE);
            mViewBinding.ivUnCertificationTip.setVisibility(View.GONE);
            mViewBinding.ivTeacherEntryTag.setVisibility(View.GONE);
        } else if (TextUtils.equals(teacherUserInfo.entryStatus, TeacherInfoConstants.ENTRY_STATUS_PASS)) {
            //入驻审核通过
            mViewBinding.ivCertificationStatus.setVisibility(View.GONE);
            mViewBinding.ivUnCertificationTip.setVisibility(View.GONE);
            mViewBinding.ivTeacherEntryTag.setVisibility(View.VISIBLE);
        } else {
            //未通过或者未申请
            mViewBinding.ivCertificationStatus.setImageResource(R.drawable.icon_home_un_certification);
            mViewBinding.ivCertificationStatus.setVisibility(View.VISIBLE);
            mViewBinding.ivUnCertificationTip.setVisibility(View.VISIBLE);
            mViewBinding.ivTeacherEntryTag.setVisibility(View.GONE);
        }

        //音乐人认证状态
        if (TextUtils.equals(teacherUserInfo.musicianAuthStatus, TeacherInfoConstants.MUSICIAN_STATUS_PASS)) {
            mViewBinding.ivTeacherMusicPersonTag.setVisibility(View.VISIBLE);
            mViewBinding.tvMusicStatusTip.setText(getString(R.string.cert_completed_str));
        } else {
            mViewBinding.ivTeacherMusicPersonTag.setVisibility(View.GONE);
            mViewBinding.tvMusicStatusTip.setText(getString(R.string.un_cert_str));
        }
    }


    @Override
    protected FragmentMineLayoutBinding getLayoutView() {
        return FragmentMineLayoutBinding.inflate(getLayoutInflater());
    }

    @Override
    protected MinePresenter createPresenter() {
        return new MinePresenter();
    }

    @Override
    public void onClick(View v) {
        int id = v.getId();
        if (id == R.id.iv_certification_status) {
            //老师认证
            ARouter.getInstance().build(RouterPath.WebCenter.ACTIVITY_HTML)
                    .withString(WebConstants.WEB_URL, WebConstants.TEACHER_CERT)
                    .navigation();
        } else if (id == R.id.iv_un_certification_tip) {
            //关闭认证提示
            mViewBinding.ivUnCertificationTip.setVisibility(View.GONE);
        } else if (id == R.id.tv_mine_page || id == R.id.iv_mine_page) {
            //个人主页
            ARouter.getInstance().build(RouterPath.MineCenter.HOME_PAGE)
                    .navigation();
        }
    }
}
